%bcond_with tests

%global py3_shebang_flags %nil

Summary:        Virtualenv-based automation of test activities
Name:           python-tox
Version:        4.10.0
Release:        2%{?dist}
License:        MIT
URL:            https://tox.readthedocs.io/
Source0:        %{pypi_source tox}


BuildRequires:  python3-devel pyproject-rpm-macros
%if %{with tests}
BuildRequires:  /usr/bin/gcc /usr/bin/git /usr/bin/pip python3-platformdirs python3-virtualenv
BuildRequires:  /usr/bin/poetry /usr/bin/pytest /usr/bin/python python3-chardet python3-colorama python3-filelock
BuildRequires:  libffi-devel python3-hatchling python3-hatch-vcs python3-cachetools
BuildRequires:  python3-pytest-xdist tox = %{version}-%{release}
%endif

BuildArch:      noarch

%description 
This package implements a generic virtualenv management and test command line tool you can use for:
 - checking your package installs correctly with different Python versions and interpreters.
 - running your tests in each of the environments, configuring your test tool of choice.
 - acting as a frontend to Continuous Integration servers, greatly reducing boilerplate and 
   merging CI and shell-based testing.


%package -n tox
Summary:        %{summary}
Provides:       python-tox = %{version}-%{release}
Provides:       python3-tox = %{version}-%{release}
Recommends:     python3-devel

%description -n tox 
%{description}


%prep
%autosetup -p1 -n tox-%{version}

	
sed -ri -e 's/"(packaging|filelock|platformdirs|psutil|diff-cover|pyproject-api|pytest|pytest-mock|pytest-xdist|wheel|pluggy|distlib|cachetools)>=.*/"\1",/g' \
        -e "s/'(time-machine)>=[^;']+/'\1/" \
        -e 's/"(virtualenv)>=.*/"\1>=20",/g' \
        -e 's/"(hatchling)>=.*/"\1>=1.13",/g' \
    pyproject.toml

%generate_buildrequires
%pyproject_buildrequires -r %{?with_tests:-x testing}


%build
%pyproject_wheel


%install
%pyproject_install
%pyproject_save_files tox


%if %{with tests}
%check
%pytest -n auto
%endif


%files -n tox -f %{pyproject_files}
%{_bindir}/tox
%{python3_sitelib}/*

%changelog
* Fri Aug 16 2024 OpenCloudOS Release Engineering <releng@opencloudos.tech> - 4.10.0-2
- Rebuilt for loongarch release

* Mon Sep 25 2023 cunshunxia <cunshunxia@tencent.com> - 4.10.0-1
- Upgrade to version 4.10.0

* Tue Sep 19 2023 OpenCloudOS Release Engineering <releng@opencloudos.tech> - 3.24.5-5
- Rebuilt for python 3.11

* Fri Sep 08 2023 OpenCloudOS Release Engineering <releng@opencloudos.tech> - 3.24.5-4
- Rebuilt for OpenCloudOS Stream 23.09

* Fri Apr 28 2023 OpenCloudOS Release Engineering <releng@opencloudos.tech> - 3.24.5-3
- Rebuilt for OpenCloudOS Stream 23.05

* Fri Mar 31 2023 OpenCloudOS Release Engineering <releng@opencloudos.tech> - 3.24.5-2
- Rebuilt for OpenCloudOS Stream 23

* Thu Dec 22 2022 Wang Guodong <gordonwwang@tencent.com> - 3.24.5-1
- package init.
